@@ -28,10 +28,11 @@ include/rdsh.h - Shared definitions for RPLD/INFO/RPLINFO
 #include <pthread.h>
 #include <stdint.h>
 #include <libHX.h>
-#if !defined(_LIBHX_H) || _LIBHX_H < 20050105
-#    error -----------------------------------------------------
-#    error You need a newer version of libHX (at least 20050105)
-#    error -----------------------------------------------------
+#if !defined(_LIBHX_H) || _LIBHX_H < 20050206
+#    error ---------------------------------------------------------
+#    error You need a newer version of libHX (at least 0_3-20050206)
+#    error http://linux01.org:2222/prog-libHX.php
+#    error ---------------------------------------------------------
 #endif
 
 #define RECEIVE_FULL(fd, ptr, sz) \
