@@ -77,7 +77,6 @@ static int pconfig_user(const char *, unsigned char, void *, void *);
 inline static const char *basename(const char *);
 static char *getnamefromuid(uid_t, char *, size_t);
 static uid_t getuidfromname(const char *);
-inline static int value_cmp(void *, void *);
 
 // Global variables (begin with uppercase character)
 static void *Buffer = NULL;
@@ -131,8 +130,7 @@ int main(int argc, const char **argv) {
         );
     }
 
-    if((Ttys = HXbtree_init(HXBT_ASSOC | HXBT_LKEY | HXBT_XCPY |
-     HXBT_FCMP, value_cmp)) == NULL) {
+    if((Ttys = HXbtree_init(HXBT_MAP | HXBT_ICMP | HXBT_NCID)) == NULL) {
         perror("Ttys = HXbtree_init()");
         return EXIT_FAILURE;
     }
@@ -702,8 +700,4 @@ static uid_t getuidfromname(const char *name) {
     return ep->pw_uid;
 }
 
-inline static int value_cmp(void *pa, void *pb) {
-    return pa - pb;
-}
-
 //==[ End of file ]============================================================
